@@ -1,8 +1,10 @@
-CONFIGMAP_FILE_ENVIRONMENT = "CONFIGMAP_FILE"
+CONFIGMAP_FILE_ENVIRONMENT = "PYMS_CONFIGMAP_FILE"
+CONFIGMAP_FILE_ENVIRONMENT_LEGACY = "CONFIGMAP_FILE"
 
 DEFAULT_CONFIGMAP_FILENAME = "config.yml"
 
-CRYPT_FILE_KEY_ENVIRONMENT = "KEY_FILE"
+CRYPT_FILE_KEY_ENVIRONMENT = "PYMS_KEY_FILE"
+CRYPT_FILE_KEY_ENVIRONMENT_LEGACY = "KEY_FILE"
 
 DEFAULT_KEY_FILENAME = "key.key"
 
