@@ -1,5 +1,4 @@
 from .create_app import Microservice
 from .create_config import config
 
-
-__all__ = ['Microservice', 'config']
+__all__ = ["Microservice", "config"]
