@@ -6,72 +6,23 @@ from flask import Flask
 
 from pyms.config.conf import validate_conf
 from pyms.config.resource import ConfigResource
-from pyms.constants import LOGGER_NAME, CONFIG_BASE
+from pyms.constants import CONFIG_BASE, LOGGER_NAME
 from pyms.crypt.driver import CryptResource
-from pyms.flask.app.utils import SingletonMeta, ReverseProxied
-from pyms.flask.healthcheck import healthcheck_blueprint
+from pyms.flask.app.utils import ReverseProxied, SingletonMeta
 from pyms.flask.configreload import configreload_blueprint
-from pyms.flask.services.driver import ServicesResource, DriverService
+from pyms.flask.healthcheck import healthcheck_blueprint
+from pyms.flask.services.driver import DriverService, ServicesResource
 from pyms.logger import CustomJsonFormatter
-from pyms.utils import check_package_exists, import_from
+from pyms.utils import check_package_exists
 
 logger = logging.getLogger(LOGGER_NAME)
 
 
 class Microservice(ConfigResource, metaclass=SingletonMeta):
     """The class Microservice is the core of all microservices built with PyMS.
-    You can create a simple microservice such as:
-    ```python
-    from flask import jsonify
-
-    from pyms.flask.app import Microservice
-
-    ms = Microservice(service="my-minimal-microservice", path=__file__)
-    app = ms.create_app()
-
-
-    @app.route("/")
-    def example():
-        return jsonify({"main": "hello world"})
-
-
-    if __name__ == '__main__':
-        app.run()
-    ```
-    Environments variables of PyMS:
-    **PYMS_CONFIGMAP_FILE**: The path to the configuration file. By default, PyMS search the configuration file in your
-    actual folder with the name "config.yml"
-
-    ## Create configuration
-    Each microservice needs a config file in yaml or json format to work with it. This configuration contains
-    the Flask settings of your project and the [Services](services.md). With this way to create configuration files, we
-    solve two problems of the [12 Factor apps](https://12factor.net/):
-    - Store config out of the code
-    - Dev/prod parity: the configuration could be injected and not depends of our code, for example, Kubernetes config maps
-
-    a simple configuration file could be a config.yaml:
-
-    ```yaml
-    pyms:
-      services:
-        requests: true
-        swagger:
-          path: ""
-          file: "swagger.yaml"
-      config:
-        DEBUG: true
-        TESTING: false
-        APP_NAME: "Python Microservice"
-        APPLICATION_ROOT: ""
-    ```
-
-    Services are libraries, resources and extensions added to the Microservice in the configuration file.
-    This services are created as an attribute of the [Microservice class](ms_class.md) to use in the code.
-
-    To add a service check the [configuration section](configuration.md).
-
-    Current services are swagger, request, tracer, metrics
+    See this docs: https://python-microservices.github.io/ms_class/
     """
+
     config_resource = CONFIG_BASE
     services: List[str] = []
     application = Flask
@@ -109,6 +60,12 @@ class Microservice(ConfigResource, metaclass=SingletonMeta):
                 self.services.append(service_name)
                 setattr(self, service_name, service)
 
+    def init_services_actions(self):
+        for service_name in self.services:
+            srv_action = getattr(getattr(self, service_name), "init_action")
+            if srv_action:
+                srv_action(self)
+
     def init_crypt(self, *args, **kwargs) -> None:
         """
         Set the Attributes of all service defined in config.yml and exists in `pyms.flask.service` module
@@ -135,22 +92,13 @@ class Microservice(ConfigResource, metaclass=SingletonMeta):
         """
         return self.application
 
-    def init_tracer(self) -> None:
-        """Set attribute in flask `tracer`. See in `pyms.flask.services.tracer` how it works
-        :return: None
-        """
-        if self.tracer:
-            FlaskTracing = import_from("flask_opentracing", "FlaskTracing")
-            client = self.tracer.get_client()
-            self.application.tracer = FlaskTracing(client, True, self.application)
-
     def init_logger(self) -> None:
         """
         Set a logger and return in JSON format.
         :return:
         """
         self.application.logger = logger
-        os.environ['WERKZEUG_RUN_MAIN'] = "true"
+        os.environ["WERKZEUG_RUN_MAIN"] = "true"
 
         formatter = CustomJsonFormatter()
         formatter.add_service_name(self.application.config["APP_NAME"])
@@ -175,8 +123,11 @@ class Microservice(ConfigResource, metaclass=SingletonMeta):
             application = self.swagger.init_app(config=self.config.to_flask(), path=self.path)
         else:
             check_package_exists("flask")
-            application = Flask(__name__, static_folder=os.path.join(self.path, 'static'),
-                                template_folder=os.path.join(self.path, 'templates'))
+            application = Flask(
+                __name__,
+                static_folder=os.path.join(self.path, "static"),
+                template_folder=os.path.join(self.path, "templates"),
+            )
 
         application.root_path = self.path
 
@@ -185,18 +136,6 @@ class Microservice(ConfigResource, metaclass=SingletonMeta):
 
         return application
 
-    def init_metrics(self) -> None:
-        """Set attribute in flask `metrics`. See in `pyms.flask.services.metrics` how it works
-        :return: None
-        """
-        if self.metrics:
-            self.application.register_blueprint(self.metrics.metrics_blueprint)
-            self.metrics.add_logger_handler(
-                self.application.logger,
-                self.application.config["APP_NAME"]
-            )
-            self.metrics.monitor(self.application.config["APP_NAME"], self.application)
-
     def reload_conf(self):
         self.delete_services()
         self.config.reload()
@@ -205,7 +144,7 @@ class Microservice(ConfigResource, metaclass=SingletonMeta):
         self.crypt.config.reload()
         self.create_app()
 
-    def create_app(self):
+    def create_app(self) -> Flask:
         """Initialize the Flask app, register blueprints and initialize
         all libraries like Swagger, database,
         the trace system...
@@ -214,7 +153,6 @@ class Microservice(ConfigResource, metaclass=SingletonMeta):
         """
         self.application = self.init_app()
         self.application.config.from_object(self.config.to_flask())
-        self.application.tracer = None
         self.application.ms = self
 
         # Initialize Blueprints
@@ -223,24 +161,21 @@ class Microservice(ConfigResource, metaclass=SingletonMeta):
 
         self.init_libs()
         self.add_error_handlers()
-
-        self.init_tracer()
-
         self.init_logger()
 
-        self.init_metrics()
+        self.init_services_actions()
 
         logger.debug("Started app with PyMS and this services: {}".format(self.services))
 
         return self.application
 
-    def add_error_handlers(self):
+    def add_error_handlers(self) -> None:
         """Subclasses will override this method in order to add specific error handlers. This should be done with
         calls to add_error_handler method.
         """
         pass
 
-    def add_error_handler(self, code_or_exception, handler):
+    def add_error_handler(self, code_or_exception, handler) -> None:
         """Add custom handler for an error code or exception in the connexion app.
 
         :param code_or_exception: HTTP error code or exception
