@@ -1,9 +1,9 @@
 import logging
-from typing import Text, Tuple, Iterator
+from typing import Iterator, Text, Tuple
 
 from pyms.config import ConfFile
 from pyms.config.resource import ConfigResource
-from pyms.constants import SERVICE_BASE, LOGGER_NAME
+from pyms.constants import LOGGER_NAME, SERVICE_BASE
 from pyms.utils import import_from
 
 logger = logging.getLogger(LOGGER_NAME)
@@ -15,38 +15,26 @@ def get_service_name(service_base: str = SERVICE_BASE, service: str = "") -> str
 
 class DriverService(ConfigResource):
     """All services must inherit from this class. This set the configuration. If we have got his config file:
-    ```
-    pyms:
-      services:
-        metrics: true
-        requests:
-          data: data
-        swagger:
-          path: ""
-          file: "swagger.yaml"
-        tracer:
-          client: "jaeger"
-          host: "localhost"
-          component_name: "Python Microservice"
-      config:
-        DEBUG: true
-        TESTING: true
-    ```
-    * `pyms.services` block is the default key to load in the pyms.flask.app.create_app.Microservice class.
-        * `metrics`: is set as the service `pyms.services.metrics`
-        * `swagger`: is set as the service `pyms.services.swagger`
-        * `tracer`: is set as the service `pyms.services.tracer`
+    See these docs:
+    * https://python-microservices.github.io/configuration/
+    * https://python-microservices.github.io/services/
     """
+
     enabled = True
 
+    init_action = False
+
     def __init__(self, *args, **kwargs):
         self.config_resource = get_service_name(service=self.config_resource)
         super().__init__(*args, **kwargs)
 
     def __getattr__(self, attr, *args, **kwargs):
         config_attribute = getattr(self.config, attr)
-        return config_attribute if config_attribute == "" or config_attribute != {} else self.default_values.get(attr,
-                                                                                                                 None)
+        return (
+            config_attribute
+            if config_attribute == "" or config_attribute != {}
+            else self.default_values.get(attr, None)
+        )
 
     def is_enabled(self) -> bool:
         return self.enabled
@@ -58,7 +46,11 @@ class DriverService(ConfigResource):
 class ServicesResource(ConfigResource):
     """This class works between `pyms.flask.create_app.Microservice` and `pyms.flask.services.[THESERVICE]`. Search
     for a file with the name you want to load, set the configuration and return a instance of the class you want
+    See these docs:
+    * https://python-microservices.github.io/configuration/
+    * https://python-microservices.github.io/services/
     """
+
     config_resource = SERVICE_BASE
 
     def get_services(self) -> Iterator[Tuple[Text, DriverService]]:
